>  我利用了几乎所有的业余时间设计了Fishconsole Project，虽然现在十分拉跨，但正努力前行


- 它是一个集成各种python操作的一个快速开发的工具集，它有缓存读写，各类中文模块，可以帮助你快速开发，它使用中文变量编程，让开发不再困难


- 导入的语法是from Fishconsole import （你需要的模块），由pycharm+win10（20h1）+python3.8.8编写，随心更新，长期项目，始于2022年富有朝气的3月

----

# 🦈Fishconsole 小鱼控制台功能一览
##### logs模块
- 原生控制台指定文字的颜色修改
- 可以染色的分割线
- 可以染色的日志输出
- 可以染色的input输入加强
- 安全退出
------------

##### easygui中文模块（window）
- 弹出窗口
- 文件选择
- <还有很多>

------------

##### matplotlib中文模块（huitu）
- 饼图，条形图，折线图，子图
- <还有很多>

------------

##### 核心模块（Fishsys）

- 加解密  
- “批量”下载网易云上的音乐
- 排名
- 检测文件存在情况
- 配置存储器
- 文本转str类型的Unicode

< 自己去看帮助文档 ~

------------



##### 文件操作模块（files）

- 强制类型检测  
- 文件存在性检测
- 缓存模块

------------






**划重点：中文变量，辅助**

**请使用：print(helps.帮助())查看内置教程或检测更新**

**请注意：针对termux的内置教程已停止更新（2022/4/13）**

**首次启动将会出现各种问题，你只需要先导入一次Fishsys模块获得许可文件就可以使用了**



------------

# 🦈Fishconsole 小鱼控制台 1.1130（2022/5/29）


1. 架构调整，受影响的组件有（缓存，文件存在性检测，系统日志，强制类型检测）


2. 移除了网易云下载器模块（帮助文档已更新）


3. 加入了全新的项目文件files，目前有缓存，文件存在性检测被移了过去，后面如果有新的跟文件有关的将会全部装在files中（帮助文档/xmind同步更新）


4. 强制更新系统程序组升级到2.5，我们解决了一部分问题，适配了缓存模块的2.0版本，这减少了一部分的代码量（xmind同步更新）


5. fcv_debug对整个集合的调控方式由返回字典转为操控缓存，这极大的减轻了后期的对某个模块单项控制的难度，同时，因为它是一个类终端的交互式调控器，所以我能加入的功能会非常的多，在此同时，我们开放了这个控制系统，现在我们已经将相关的操纵代码贴到了帮助文档，你可以去看一下（帮助文档/xmind同步更新）


6. 系统日志被调到了Fishsys，这可以解决一部分循环导入的问题，这和调走缓存和文件存在性检测一样是30版最骄傲的地方（架构调整）


7.  缓存模块升级，现在的它可以在指定在类dict的文件中找到指定的参数，并且相比之前具备了更加完善的异常处理机制，但我为了方便维护暂时取消了密码模块的保护，这意味着之前的Fishconsole.fcc文件将要被删除，原来的缓存文件将不再可用，如果强行要升级你的缓存文件，你可以尝试在上一个版本中加载该文件（如果遇到强制更新系统阻拦，你可以去fcv_debug1.0中修改返回的数据或者直接修改mod的值为False），将它存放在另一个位置就能完成对缓存的升级（帮助文档/xmind同步更新）（xmind/帮助文档同步更新）


8. logs.变量查看更新，这次更新我们修复了因为数据太多导致的边界线长的离谱的问题，并且将横排数据转换为竖排数据，这样做就能处理一些大数据了（比如网页）（xmind已更新）


9. md文档维护更新（未完成）


10. 系统日志更新（xmind已更新）


11. 尝试把所有的无效语句换成pass（待研究） 


12. 在测试时移动了强制类型检测，这样做又解决了一个循环导入的报错（xmind更新）（帮助文档更新）（xmind完成）


13. fcv_debug console将新增命令：execute（执行cmd语句）（待研究）


14. 缓存模块升级：3，插入模式（待研究）


------------
# 🦈Fishconsole 小鱼控制台 1.1129（2022/5/20）


1. 强制更新程序组修复致命错误，其他问题还待检测，1.1128版本将被删除（Fishsys）


------------

# 🦈Fishconsole 小鱼控制台 1.1128（2022/5/20）


1. 强制更新程序组二期完工 - 配置自动更新，不需要你去控制台敲pip了


2. 修复了一个变量查看的一个疏忽


3. 缓存读取模块更新，加入异常处理



         ~~情人节快乐！！！！！~~



------------

# 🦈Fishconsole 小鱼控制台 1.1127（2022/5/18）

1. 为整个模块适配最后的强制类型检测


2. 修改Md文档 


3. (内部调整)将帮助文档扩展到每一个模块的简介，具体请在pycharm中将将鼠标移到任意一个函数


4. （内部调整）LOGS变量查看更新（边框长度自动变化（这个东西的意义就是避免长度不够造成一些视觉上的无语），虽然不会调整多少（因为如果太精确的化会吃算力））


5. 新增讯飞云控（帮助文档，思维导图同步更新）


6. 新增官网存活性检测（帮助文档，思维导图同步更新）


7. （内部调整）采用全新的开发方式，正在慢慢的应用于全部，大部分的模块都将被修改


8. 网易云音乐模块更新：增加异常处理


9. （内部调整）安全退出更新，如果传入变量名将会自动激活变量查看


10. 缓存模块更新（新增强制类型检测dict）


11. 为所有的模块都做了简介
------------

# 🦈Fishconsole 小鱼控制台 1.1126（2022/5/15）

1. 为整个模块适配强制类型检测


2. 针对jupyter的exit退出报错的问题，我们准备采用统一的退出方式替换exit


3. （内部调整）logs新增安全退出（帮助文档不更新）


4. （变量查看新增行数信息）


5. （变量查看优化了类型的显示）


------------

# 🦈Fishconsole 小鱼控制台 1.1124（2022/5/13）

1. 思维导图现已加入到Fishconsole工程目录中，它将会和帮助文档一并更新


2.  新增强制类型检测（帮助文档&xmind同步更新）


------------

# 🦈Fishconsole 小鱼控制台 1.1123（2022/5/9）

1. 我会在模块包中加入思维导图，这不仅方便了你，也方便了我，获得方法，下载未来的1.1124的gz包然后解压自己找


2. 密码模块开发者选项(实验版)计划由于技术不够被强行终止（清理垃圾代码以免造成新的屎山）。在未来，我将会在后面的功能中尽量避开使用这个该死的模块（PCI）


3. tool新增变量类型查看器（帮助文档同步更新）


4. tool模块已更名为Fishsys


5. Md文档维护更新
------------

# 🦈Fishconsole 小鱼控制台 1.1122紧急更新（2022/4/27）


1. 修改了一下Markdown的问题（没做完）


2. 修复绘图模块（饼图）的（中文乱码）


3. 修复新的密码模块的致命问题
   

4. 新的密码模块开发者选项已加入(实验版)


5. 稍微处理了一下屎山

         ~~我要打个哈欠o(〃'▽'〃)o~~

------------

# 🦈Fishconsole 小鱼控制台 1.1121更新（2022/4/26）

1. 补充了logs模块当中输出颜色中缺失的绿色（logs拥有色选参数的所有模块将全部支持输出绿色文字）（帮助文档同步更新）


2. 反转tool.文件存在性检测模块结果不准确的问题（帮助文档同步更新）


3. 新增类型控制，未来将在某些时候彻底只允许指定类型的数据进入（如果是万不得已的情况下）,全部功能正在修改
   

4. 新增错误跟踪器（不提供帮助文档）


5. 优化Fishconsole专用输出，并纳入f_debug控制范围（不提供帮助文档）


6. 在tool中加入参数存储器完全体（帮助文档同步更新） 


7.  为helps添加最新的外观特性，并修改了一下常见问题


8. 修复Logs颜色的历史遗留的选项不对应功能的问题，去掉了黑色的背景，删除了一些颜色（如果你的颜色不在规则范围内，我们将提供原文）（我tm换了主题才发现的，无语了属于是）（帮助文档同步更新）


9. 新增Fishconsole 开发者模式（f_debug）（不提供帮助文档）


10. 新增基于f_debug的Fishconsole强制更新机制（解除方法是更新本模块后重新运行helps.帮助）


11. 修改系统日志的输出方式以支持f_debug对整个模组的控制


12. 增强helps的辅助功能，比如让他成为强制更新机制的控制器


13. 美化输入功能


14. 将tool模块作为执行强制更新系统执行器（版本低于最新版将不允许本模块被调用） 


15. 原密码模块已被套壳，现在的密码模块已支持（几乎所有文字），原来的密码模块被重命名为passwordsys（帮助文档同步更新）


16. tool模块新增文本转Unicode（帮助文档同步更新）


17. 增加f_debug的控制范围到unicode模块的系统级消息输出，password模块系统级消息输出，后续将会控制更多位置以更好的管理越来越庞大的模块


18. 修复在使用帮助文档的过程中意外关闭窗口导致回调None让后面的程序无法运行而报错的问题


19. 开发者选项完善计划正在覆盖至tool全模块以辅助强制更新系统的漏洞（缓存被非法覆盖）修复


20. （内部调整）修复fcv_debug早期编写时的逻辑问题，使其稳定性更强，更加简洁


21. （内部调整）我们将在模块当中加入大量注释以及系统日志，虽然会影响模块的速度，但是对管理上来说是个不错的选择（毕竟所有大模块都在做，我也从强制更新系统的开发中尝到了广用注释的甜头）


22. f_debug已完成对所有核心组件的系统日志的输出控制


         ~~我要打个哈欠o(〃'▽'〃)o~~

------------

# 🦈Fishconsole 小鱼控制台 1.1120更新（2022/4/15）

1. 我在logs基础模块中添加了一个新的功能，也就是输入的辅助功能（帮助文档同步更新）


2. 修改了一下Markdown的问题


   

         ~~我要打个哈欠o(〃'▽'〃)o~~

------------

# 🦈Fishconsole 小鱼控制台1.1119更新

1. 修复了排名指定第几个的时候跳了一次的问题


2. 修改了一下Markdown的问题


3. 加入检测文件是否存在的功能到tool模块 ，帮助文档同步更新


4. 重新加回日志和分割线的颜色，它的用法就是在原来的基础上加了色选的参数，用法和颜色的用法是一样的,然后对分割线做了一丢丢美化（帮助文档同步更新）


5. 暂时不打算去掉针对termux的内置教程但不会去维护它（主要是太懒了）


6. 修复了帮助文档的问题（工欲善其事，必先利其器）





      ~~我要打个哈欠o(〃'▽'〃)o~~


------------

# 🦈Fishconsole 小鱼控制台1.1118更新


1. 将除控制台输出模块的其他内容改为用easygui编写,但是命令行文档将会保留，主要针对的是可能的termux用户


2. 对下载这个模块提供了更完整的要求 


3.  新增matplotlib 中文辅助模块，帮助文档同步更新


4.  去除logs.分割线()当中已经失效了的颜色选择，现在如果想在logs.分割线()中添加颜色，请使用“logs.颜色（logs.分割线（））”

   
5.  logs模块当中新增背景色，具体可以使用**print(helps.帮助())查看内置教程**


6. 新增tool模块，这相当于是我的一个代码仓库吧，我以后写的所有可以拿来用的小程序全都会放在这里（是不是很过分☕😉）


7. 网易云音乐下载器加入到tool模块中，帮助文档同步更新


8. 加密解密器已加入到tool模块中，帮助文档同步更新


9. 排名模块已加入到tool模块中 ，帮助文档同步更新


      ~~我要打个哈欠o(〃'▽'〃)o~~

------------

# 🦈Fishconsole 小鱼控制台1.1115更新
1. 现在导入包的名字为“from Fishconsole import *”
2. 改了一下window模块的提示参数
3. 将除控制台输出模块的其他内容改为用easygui编写（主要是后期越来越多的模块会让整个文档看起来非常吃力，所以必须使用这种方式）（还没开始嘿嘿）
4. 对下载这个模块提供了完整的要求 
   

      ~~我要打个哈欠o(〃'▽'〃)o~~

------------

# 🦈Fishconsole 小鱼控制台 1.1114更新
1. 加入easygui中文辅助模块
2. 完善模块，拆分功能

         ~~我要打个哈欠o(〃'▽'〃)o~~
